@@ -1,9 +1,7 @@
 use strict;
 use warnings;
 package Mail::SendGrid;
-{
-  $Mail::SendGrid::VERSION = '0.07';
-}
+$Mail::SendGrid::VERSION = '0.08';
 # ABSTRACT: interface to SendGrid.com mail gateway APIs
 
 use 5.008;
@@ -154,7 +152,7 @@ Mail::SendGrid - interface to SendGrid.com mail gateway APIs
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 SYNOPSIS
 
@@ -273,6 +271,10 @@ L<http://sendgrid.com/docs/API%20Reference/Web%20API/bounces.html>
 
 =back
 
+=head1 REPOSITORY
+
+L<https://github.com/neilb/Mail-SendGrid>
+
 =head1 AUTHOR
 
 Neil Bowers <neilb@cpan.org>
